@@ -92,7 +92,12 @@ macro_rules! select_view {
 macro_rules! settings {
     ($title:expr, $save_cb:expr, $($view:expr), *) => {
         {
-            use cursive::views::{Dialog, LinearLayout};
+            use cursive::{
+                traits::With,
+                views::{Dialog, LinearLayout, OnEventView},
+                event::{Key, Event}
+            };
+
             Dialog::around(
                 LinearLayout::vertical()
                 $(
@@ -102,6 +107,8 @@ macro_rules! settings {
             .dismiss_button("Back")
             .button("Save", $save_cb)
             .title($title)
+            .wrap_with(OnEventView::new)
+            .on_event(Event::Key(Key::Esc), |v| { v.pop_layer(); })
         }
     };
 }
